# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`openssl`](#openssl): Installs openssl and ensures bundled certificate list is world readable
* [`openssl::certificates`](#openssl--certificates): Generates x509 certificates based on class parameters
* [`openssl::configs`](#openssl--configs): Generates openssl.conf files using manually set defaults or defaults from openssl::config
* [`openssl::packages`](#openssl--packages): Sets up packages for openssl

### Defined types

* [`openssl::certificate::x509`](#openssl--certificate--x509): Creates a certificate, key and CSR according to datas provided.
* [`openssl::config`](#openssl--config): Generates an openssl.conf file using defaults
* [`openssl::dhparam`](#openssl--dhparam): Creates Diffie Helman parameters.
* [`openssl::export::pem_cert`](#openssl--export--pem_cert): Export certificate(s) to PEM/x509 format
* [`openssl::export::pem_key`](#openssl--export--pem_key): Export a key to PEM format
* [`openssl::export::pkcs12`](#openssl--export--pkcs12): Export a key pair to PKCS12 format

### Resource types

* [`cert_file`](#cert_file): Manages X.509 certificate files downloaded from a source location, saved in the specified format.
* [`dhparam`](#dhparam): A Diffie Helman parameter file
* [`ssl_pkey`](#ssl_pkey): An SSL private key
* [`x509_cert`](#x509_cert): An x509 certificate
* [`x509_request`](#x509_request): An x509 certificate signing request

### Functions

* [`openssl::cert_aia_caissuers`](#openssl--cert_aia_caissuers): Extrating the caIssuers entry from Authority Information Access extension of X509 certificate
* [`openssl::cert_date_valid`](#openssl--cert_date_valid): Checks SSL cetificate date validity.

## Classes

### <a name="openssl"></a>`openssl`

Installs openssl and ensures bundled certificate list is world readable

#### Examples

##### basic usage

```puppet
class { 'openssl':
  package_name           => 'openssl-othername',
  package_ensure         => latest,
  ca_certificates_ensure => latest,
}
```

#### Parameters

The following parameters are available in the `openssl` class:

* [`package_name`](#-openssl--package_name)
* [`package_ensure`](#-openssl--package_ensure)
* [`ca_certificates_ensure`](#-openssl--ca_certificates_ensure)

##### <a name="-openssl--package_name"></a>`package_name`

Data type: `Optional[String[1]]`

openssl package name

Default value: `undef`

##### <a name="-openssl--package_ensure"></a>`package_ensure`

Data type: `String[1]`

openssl package ensure

Default value: `installed`

##### <a name="-openssl--ca_certificates_ensure"></a>`ca_certificates_ensure`

Data type: `String[1]`

ca-certificates package ensure

Default value: `installed`

### <a name="openssl--certificates"></a>`openssl::certificates`

Generates x509 certificates based on class parameters

#### Examples

##### basic usage

```puppet
class { 'openssl::certificate':
  x509_certs => { '/path/to/certificate.crt' => {  ensure      => 'present',
                                                   password    => 'j(D$',
                                                   template    => '/other/path/to/template.cnf',
                                                   private_key => '/there/is/my/private.key',
                                                   days        => 4536,
                                                   force       => false,},
                  '/a/other/certificate.crt' => {  ensure      => 'present', },
                }
}
```

#### Parameters

The following parameters are available in the `openssl::certificates` class:

* [`x509_certs`](#-openssl--certificates--x509_certs)

##### <a name="-openssl--certificates--x509_certs"></a>`x509_certs`

Data type: `Hash`



Default value: `{}`

### <a name="openssl--configs"></a>`openssl::configs`

Generates openssl.conf files using manually set defaults or defaults from openssl::config

#### Examples

##### basic usage

```puppet
class { 'openssl::configs':
  country   => 'mycountry',
  conffiles => { '/path/to/openssl.conf' => { ensure       => 'present',
                                              commonname   => 'somewhere.org',
                                              organization => 'myorg' },
                 '/a/other/openssl.conf' => { ensure       => 'present',
                                              commonname   => 'somewhere.else.org',
                                              organization => 'myotherorg' },
                }
}
```

#### Parameters

The following parameters are available in the `openssl::configs` class:

* [`owner`](#-openssl--configs--owner)
* [`group`](#-openssl--configs--group)
* [`mode`](#-openssl--configs--mode)
* [`country`](#-openssl--configs--country)
* [`state`](#-openssl--configs--state)
* [`locality`](#-openssl--configs--locality)
* [`organization`](#-openssl--configs--organization)
* [`unit`](#-openssl--configs--unit)
* [`email`](#-openssl--configs--email)
* [`default_bits`](#-openssl--configs--default_bits)
* [`default_md`](#-openssl--configs--default_md)
* [`default_keyfile`](#-openssl--configs--default_keyfile)
* [`basicconstraints`](#-openssl--configs--basicconstraints)
* [`extendedkeyusages`](#-openssl--configs--extendedkeyusages)
* [`keyusages`](#-openssl--configs--keyusages)
* [`subjectaltnames`](#-openssl--configs--subjectaltnames)
* [`conffiles`](#-openssl--configs--conffiles)

##### <a name="-openssl--configs--owner"></a>`owner`

Data type: `Optional[String[1]]`

default owner for the configuration files

Default value: `undef`

##### <a name="-openssl--configs--group"></a>`group`

Data type: `Optional[String[1]]`

default group for the configuration files

Default value: `undef`

##### <a name="-openssl--configs--mode"></a>`mode`

Data type: `Optional[Stdlib::Filemode]`

default mode for the configuration files

Default value: `undef`

##### <a name="-openssl--configs--country"></a>`country`

Data type: `Optional[String[1]]`

default value for country

Default value: `undef`

##### <a name="-openssl--configs--state"></a>`state`

Data type: `Optional[String[1]]`

default value for state

Default value: `undef`

##### <a name="-openssl--configs--locality"></a>`locality`

Data type: `Optional[String[1]]`

default value for locality

Default value: `undef`

##### <a name="-openssl--configs--organization"></a>`organization`

Data type: `Optional[String[1]]`

default value for organization

Default value: `undef`

##### <a name="-openssl--configs--unit"></a>`unit`

Data type: `Optional[String[1]]`

default value for unit

Default value: `undef`

##### <a name="-openssl--configs--email"></a>`email`

Data type: `Optional[String[1]]`

default value for email

Default value: `undef`

##### <a name="-openssl--configs--default_bits"></a>`default_bits`

Data type: `Optional[Integer]`

default key size to generate

Default value: `undef`

##### <a name="-openssl--configs--default_md"></a>`default_md`

Data type: `Optional[String[1]]`

default message digest to use

Default value: `undef`

##### <a name="-openssl--configs--default_keyfile"></a>`default_keyfile`

Data type: `Optional[String[1]]`

default name for the keyfile

Default value: `undef`

##### <a name="-openssl--configs--basicconstraints"></a>`basicconstraints`

Data type: `Optional[Array]`

default version 3 certificate extension basic constraints

Default value: `undef`

##### <a name="-openssl--configs--extendedkeyusages"></a>`extendedkeyusages`

Data type: `Optional[Array]`

default version 3 certificate extension extended key usage

Default value: `undef`

##### <a name="-openssl--configs--keyusages"></a>`keyusages`

Data type: `Optional[Array]`

default version 3 certificate extension key usage

Default value: `undef`

##### <a name="-openssl--configs--subjectaltnames"></a>`subjectaltnames`

Data type: `Optional[Array]`

default version 3 certificate extension for alternative names
currently supported are IP (v4) and DNS

Default value: `undef`

##### <a name="-openssl--configs--conffiles"></a>`conffiles`

Data type: `Hash`

config files to generate

Default value: `{}`

### <a name="openssl--packages"></a>`openssl::packages`

Sets up packages for openssl

## Defined types

### <a name="openssl--certificate--x509"></a>`openssl::certificate::x509`

Creates a certificate, key and CSR according to datas provided.

#### Examples

##### basic usage

```puppet

openssl::certificate::x509 { 'foo.bar':
  ensure       => present,
  country      => 'CH',
  organization => 'Example.com',
  commonname   => $fqdn,
  base_dir     => '/var/www/ssl',
  owner        => 'www-data',
}

This will create files "foo.bar.cnf", "foo.bar.crt", "foo.bar.key"
and "foo.bar.csr" in /var/www/ssl/.
All files will belong to user "www-data".

Those files can be used as is for apache, openldap and so on.

If you wish to ensure a key is read-only to a process:
set $key_group to match the group of the process,
and set $key_mode to '0640'.
```

#### Parameters

The following parameters are available in the `openssl::certificate::x509` defined type:

* [`ensure`](#-openssl--certificate--x509--ensure)
* [`country`](#-openssl--certificate--x509--country)
* [`state`](#-openssl--certificate--x509--state)
* [`locality`](#-openssl--certificate--x509--locality)
* [`commonname`](#-openssl--certificate--x509--commonname)
* [`altnames`](#-openssl--certificate--x509--altnames)
* [`extkeyusage`](#-openssl--certificate--x509--extkeyusage)
* [`organization`](#-openssl--certificate--x509--organization)
* [`unit`](#-openssl--certificate--x509--unit)
* [`email`](#-openssl--certificate--x509--email)
* [`days`](#-openssl--certificate--x509--days)
* [`base_dir`](#-openssl--certificate--x509--base_dir)
* [`key_size`](#-openssl--certificate--x509--key_size)
* [`owner`](#-openssl--certificate--x509--owner)
* [`group`](#-openssl--certificate--x509--group)
* [`key_owner`](#-openssl--certificate--x509--key_owner)
* [`key_group`](#-openssl--certificate--x509--key_group)
* [`key_mode`](#-openssl--certificate--x509--key_mode)
* [`password`](#-openssl--certificate--x509--password)
* [`force`](#-openssl--certificate--x509--force)
* [`cnf_dir`](#-openssl--certificate--x509--cnf_dir)
* [`crt_dir`](#-openssl--certificate--x509--crt_dir)
* [`csr_dir`](#-openssl--certificate--x509--csr_dir)
* [`key_dir`](#-openssl--certificate--x509--key_dir)
* [`cnf`](#-openssl--certificate--x509--cnf)
* [`crt`](#-openssl--certificate--x509--crt)
* [`csr`](#-openssl--certificate--x509--csr)
* [`key`](#-openssl--certificate--x509--key)
* [`encrypted`](#-openssl--certificate--x509--encrypted)
* [`ca`](#-openssl--certificate--x509--ca)
* [`cakey`](#-openssl--certificate--x509--cakey)
* [`cakey_password`](#-openssl--certificate--x509--cakey_password)

##### <a name="-openssl--certificate--x509--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

ensure wether certif and its config are present or not

Default value: `present`

##### <a name="-openssl--certificate--x509--country"></a>`country`

Data type: `Optional[String]`

certificate countryName

Default value: `undef`

##### <a name="-openssl--certificate--x509--state"></a>`state`

Data type: `Optional[String]`

certificate stateOrProvinceName

Default value: `undef`

##### <a name="-openssl--certificate--x509--locality"></a>`locality`

Data type: `Optional[String]`

certificate localityName

Default value: `undef`

##### <a name="-openssl--certificate--x509--commonname"></a>`commonname`

Data type: `Optional[String]`

certificate CommonName

Default value: `undef`

##### <a name="-openssl--certificate--x509--altnames"></a>`altnames`

Data type: `Array`

certificate subjectAltName.
Can be an array or a single string.

Default value: `[]`

##### <a name="-openssl--certificate--x509--extkeyusage"></a>`extkeyusage`

Data type: `Array`

certificate extended key usage
Value           | Meaning
----------------|-------------------------------------
serverAuth      | SSL/TLS Web Server Authentication.
clientAuth      | SL/TLS Web Client Authentication.
codeSigning     | Code signing.
emailProtection | E-mail Protection (S/MIME).
timeStamping    | Trusted Timestamping
OCSPSigning     | OCSP Signing
ipsecIKE        | ipsec Internet Key Exchange
msCodeInd       | Microsoft Individual Code Signing (authenticode)
msCodeCom       | Microsoft Commercial Code Signing (authenticode)
msCTLSign       | Microsoft Trust List Signing
msEFS           | Microsoft Encrypted File System

Default value: `[]`

##### <a name="-openssl--certificate--x509--organization"></a>`organization`

Data type: `Optional[String]`

certificate organizationName

Default value: `undef`

##### <a name="-openssl--certificate--x509--unit"></a>`unit`

Data type: `Optional[String]`

certificate organizationalUnitName

Default value: `undef`

##### <a name="-openssl--certificate--x509--email"></a>`email`

Data type: `Optional[String]`

certificate emailAddress

Default value: `undef`

##### <a name="-openssl--certificate--x509--days"></a>`days`

Data type: `Integer`

certificate validity

Default value: `365`

##### <a name="-openssl--certificate--x509--base_dir"></a>`base_dir`

Data type: `Stdlib::Absolutepath`

where cnf, crt, csr and key should be placed.
Directory must exist

Default value: `'/etc/ssl/certs'`

##### <a name="-openssl--certificate--x509--key_size"></a>`key_size`

Data type: `Integer`

Size of the key to generate.

Default value: `3072`

##### <a name="-openssl--certificate--x509--owner"></a>`owner`

Data type: `Variant[String, Integer]`

cnf, crt, csr and key owner. User must exist

Default value: `'root'`

##### <a name="-openssl--certificate--x509--group"></a>`group`

Data type: `Variant[String, Integer]`

cnf, crt, csr and key group. Group must exist

Default value: `'root'`

##### <a name="-openssl--certificate--x509--key_owner"></a>`key_owner`

Data type: `Variant[String, Integer]`

key owner. User must exist. defaults to $owner

Default value: `$owner`

##### <a name="-openssl--certificate--x509--key_group"></a>`key_group`

Data type: `Variant[String, Integer]`

key group. Group must exist. defaults to $group

Default value: `$group`

##### <a name="-openssl--certificate--x509--key_mode"></a>`key_mode`

Data type: `Stdlib::Filemode`

key group.

Default value: `'0600'`

##### <a name="-openssl--certificate--x509--password"></a>`password`

Data type: `Optional[String]`

private key password. undef means no passphrase
will be used to encrypt private key.

Default value: `undef`

##### <a name="-openssl--certificate--x509--force"></a>`force`

Data type: `Boolean`

whether to override certificate and request
if private key changes

Default value: `true`

##### <a name="-openssl--certificate--x509--cnf_dir"></a>`cnf_dir`

Data type: `Stdlib::Absolutepath`

where cnf should be placed.
Directory must exist, defaults to $base_dir.

Default value: `$base_dir`

##### <a name="-openssl--certificate--x509--crt_dir"></a>`crt_dir`

Data type: `Stdlib::Absolutepath`

where crt should be placed.
Directory must exist, defaults to $base_dir.

Default value: `$base_dir`

##### <a name="-openssl--certificate--x509--csr_dir"></a>`csr_dir`

Data type: `Stdlib::Absolutepath`

where csr should be placed.
Directory must exist, defaults to $base_dir.

Default value: `$base_dir`

##### <a name="-openssl--certificate--x509--key_dir"></a>`key_dir`

Data type: `Stdlib::Absolutepath`

where key should be placed.
Directory must exist, defaults to $base_dir.

Default value: `$base_dir`

##### <a name="-openssl--certificate--x509--cnf"></a>`cnf`

Data type: `Stdlib::Absolutepath`

override cnf path entirely.
Directory must exist, defaults to $cnf_dir/$title.cnf

Default value: `"${cnf_dir}/${name}.cnf"`

##### <a name="-openssl--certificate--x509--crt"></a>`crt`

Data type: `Stdlib::Absolutepath`

override crt path entirely.
Directory must exist, defaults to $crt_dir/$title.crt

Default value: `"${crt_dir}/${name}.crt"`

##### <a name="-openssl--certificate--x509--csr"></a>`csr`

Data type: `Stdlib::Absolutepath`

override csr path entirely.
Directory must exist, defaults to $csr_dir/$title.csr

Default value: `"${csr_dir}/${name}.csr"`

##### <a name="-openssl--certificate--x509--key"></a>`key`

Data type: `Stdlib::Absolutepath`

override key path entirely.
Directory must exist, defaults to $key_dir/$title.key

Default value: `"${key_dir}/${name}.key"`

##### <a name="-openssl--certificate--x509--encrypted"></a>`encrypted`

Data type: `Boolean`

Flag requesting the exported key to be unencrypted by
specifying the -nodes option during the CSR generation. Turning
off encryption is needed by some applications, such as OpenLDAP.
Defaults to true (key is encrypted)

Default value: `true`

##### <a name="-openssl--certificate--x509--ca"></a>`ca`

Data type: `Optional[Stdlib::Absolutepath]`

Path to CA certificate for signing. Undef means no CA will be
provided for signing the certificate.

Default value: `undef`

##### <a name="-openssl--certificate--x509--cakey"></a>`cakey`

Data type: `Optional[Stdlib::Absolutepath]`

Path to CA private key for signing. Undef mean no CAkey will be
provided.

Default value: `undef`

##### <a name="-openssl--certificate--x509--cakey_password"></a>`cakey_password`

Data type: `Optional[Variant[Sensitive[String[1]], String[1]]]`

Optional password that has encrypted the CA key.

Default value: `undef`

### <a name="openssl--config"></a>`openssl::config`

Generates an openssl.conf file using defaults

#### Examples

##### basic usage

```puppet
openssl::config {'/path/to/openssl.conf':
  ensure       => 'present',
  commonname   => 'somewhere.org',
  country      => 'mycountry',
  organization => 'myorg',
}
```

#### Parameters

The following parameters are available in the `openssl::config` defined type:

* [`ensure`](#-openssl--config--ensure)
* [`commonname`](#-openssl--config--commonname)
* [`country`](#-openssl--config--country)
* [`organization`](#-openssl--config--organization)
* [`owner`](#-openssl--config--owner)
* [`group`](#-openssl--config--group)
* [`mode`](#-openssl--config--mode)
* [`state`](#-openssl--config--state)
* [`locality`](#-openssl--config--locality)
* [`unit`](#-openssl--config--unit)
* [`email`](#-openssl--config--email)
* [`default_bits`](#-openssl--config--default_bits)
* [`default_md`](#-openssl--config--default_md)
* [`default_keyfile`](#-openssl--config--default_keyfile)
* [`basicconstraints`](#-openssl--config--basicconstraints)
* [`extendedkeyusages`](#-openssl--config--extendedkeyusages)
* [`keyusages`](#-openssl--config--keyusages)
* [`subjectaltnames`](#-openssl--config--subjectaltnames)

##### <a name="-openssl--config--ensure"></a>`ensure`

Data type: `Enum['absent','present']`

ensure parameter for configfile; defaults to present

Default value: `'present'`

##### <a name="-openssl--config--commonname"></a>`commonname`

Data type: `Optional[Variant[String[1], Array[String[1]]]]`

commonname for config file

Default value: `undef`

##### <a name="-openssl--config--country"></a>`country`

Data type: `Optional[String[1]]`

value for country

Default value: `undef`

##### <a name="-openssl--config--organization"></a>`organization`

Data type: `Optional[String[1]]`

value for organization

Default value: `undef`

##### <a name="-openssl--config--owner"></a>`owner`

Data type: `Variant[String[1],Integer]`

owner for the configuration file

Default value: `'root'`

##### <a name="-openssl--config--group"></a>`group`

Data type: `Variant[String[1],Integer]`

group for the configuration file

Default value: `'root'`

##### <a name="-openssl--config--mode"></a>`mode`

Data type: `Stdlib::Filemode`

mode for the configuration file

Default value: `'0640'`

##### <a name="-openssl--config--state"></a>`state`

Data type: `Optional[String[1]]`

value for state

Default value: `undef`

##### <a name="-openssl--config--locality"></a>`locality`

Data type: `Optional[String[1]]`

value for locality

Default value: `undef`

##### <a name="-openssl--config--unit"></a>`unit`

Data type: `Optional[String[1]]`

value for unit

Default value: `undef`

##### <a name="-openssl--config--email"></a>`email`

Data type: `Optional[String[1]]`

value for email

Default value: `undef`

##### <a name="-openssl--config--default_bits"></a>`default_bits`

Data type: `Integer`

key size to generate

Default value: `4096`

##### <a name="-openssl--config--default_md"></a>`default_md`

Data type: `String[1]`

message digest to use

Default value: `'sha512'`

##### <a name="-openssl--config--default_keyfile"></a>`default_keyfile`

Data type: `String[1]`

name for the keyfile

Default value: `'privkey.pem'`

##### <a name="-openssl--config--basicconstraints"></a>`basicconstraints`

Data type: `Array`

version 3 certificate extension basic constraints

Default value: `[]`

##### <a name="-openssl--config--extendedkeyusages"></a>`extendedkeyusages`

Data type: `Array`

version 3 certificate extension extended key usage

Default value: `[]`

##### <a name="-openssl--config--keyusages"></a>`keyusages`

Data type: `Array`

version 3 certificate extension key usage

Default value: `[]`

##### <a name="-openssl--config--subjectaltnames"></a>`subjectaltnames`

Data type: `Array`

version 3 certificate extension for alternative names
currently supported are IP (v4) and DNS

Default value: `[]`

### <a name="openssl--dhparam"></a>`openssl::dhparam`

Creates Diffie Helman parameters.

#### Parameters

The following parameters are available in the `openssl::dhparam` defined type:

* [`path`](#-openssl--dhparam--path)
* [`ensure`](#-openssl--dhparam--ensure)
* [`size`](#-openssl--dhparam--size)
* [`owner`](#-openssl--dhparam--owner)
* [`group`](#-openssl--dhparam--group)
* [`mode`](#-openssl--dhparam--mode)
* [`fastmode`](#-openssl--dhparam--fastmode)

##### <a name="-openssl--dhparam--path"></a>`path`

Data type: `Stdlib::Absolutepath`

path to write DH parameters to

Default value: `$name`

##### <a name="-openssl--dhparam--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

ensure whether DH paramers file is present or absent

Default value: `present`

##### <a name="-openssl--dhparam--size"></a>`size`

Data type: `Integer[1]`

number of bits for the parameter set

Default value: `2048`

##### <a name="-openssl--dhparam--owner"></a>`owner`

Data type: `Variant[String, Integer]`

file owner. User must exist

Default value: `'root'`

##### <a name="-openssl--dhparam--group"></a>`group`

Data type: `Variant[String, Integer]`

file group. Group must exist

Default value: `'root'`

##### <a name="-openssl--dhparam--mode"></a>`mode`

Data type: `Stdlib::Filemode`

file mode.

Default value: `'0644'`

##### <a name="-openssl--dhparam--fastmode"></a>`fastmode`

Data type: `Boolean`

Use "fastmode" for dhparam generation

Default value: `false`

### <a name="openssl--export--pem_cert"></a>`openssl::export::pem_cert`

Export certificate(s) to PEM/x509 format

#### Parameters

The following parameters are available in the `openssl::export::pem_cert` defined type:

* [`dynamic`](#-openssl--export--pem_cert--dynamic)
* [`ensure`](#-openssl--export--pem_cert--ensure)
* [`resources`](#-openssl--export--pem_cert--resources)
* [`pfx_cert`](#-openssl--export--pem_cert--pfx_cert)
* [`der_cert`](#-openssl--export--pem_cert--der_cert)
* [`pem_cert`](#-openssl--export--pem_cert--pem_cert)
* [`in_pass`](#-openssl--export--pem_cert--in_pass)

##### <a name="-openssl--export--pem_cert--dynamic"></a>`dynamic`

Data type: `Boolean`

dynamically renew certificate file

Default value: `false`

##### <a name="-openssl--export--pem_cert--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Whether the certificate file should exist

Default value: `present`

##### <a name="-openssl--export--pem_cert--resources"></a>`resources`

Data type: `Variant[Type, Array[Type]]`

List of resources to subscribe to for certificate file renewal

Default value: `[]`

##### <a name="-openssl--export--pem_cert--pfx_cert"></a>`pfx_cert`

Data type: `Optional[Stdlib::Absolutepath]`

PFX certificate/key container

Default value: `undef`

##### <a name="-openssl--export--pem_cert--der_cert"></a>`der_cert`

Data type: `Optional[Stdlib::Absolutepath]`

DER certificate

Default value: `undef`

##### <a name="-openssl--export--pem_cert--pem_cert"></a>`pem_cert`

Data type: `Stdlib::Absolutepath`

PEM/x509 certificate

Default value: `$title`

##### <a name="-openssl--export--pem_cert--in_pass"></a>`in_pass`

Data type: `Optional[String]`

PFX password

Default value: `undef`

### <a name="openssl--export--pem_key"></a>`openssl::export::pem_key`

Export a key to PEM format

#### Parameters

The following parameters are available in the `openssl::export::pem_key` defined type:

* [`pfx_cert`](#-openssl--export--pem_key--pfx_cert)
* [`pem_key`](#-openssl--export--pem_key--pem_key)
* [`dynamic`](#-openssl--export--pem_key--dynamic)
* [`ensure`](#-openssl--export--pem_key--ensure)
* [`resources`](#-openssl--export--pem_key--resources)
* [`in_pass`](#-openssl--export--pem_key--in_pass)
* [`out_pass`](#-openssl--export--pem_key--out_pass)

##### <a name="-openssl--export--pem_key--pfx_cert"></a>`pfx_cert`

Data type: `Stdlib::Absolutepath`

PFX certificate/key container

##### <a name="-openssl--export--pem_key--pem_key"></a>`pem_key`

Data type: `Stdlib::Absolutepath`

PEM certificate

Default value: `$title`

##### <a name="-openssl--export--pem_key--dynamic"></a>`dynamic`

Data type: `Boolean`

dynamically renew key file

Default value: `false`

##### <a name="-openssl--export--pem_key--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Whether the keyfile should exist

Default value: `present`

##### <a name="-openssl--export--pem_key--resources"></a>`resources`

Data type: `Variant[Type, Array[Type]]`

List of resources to subscribe to for key renewal

Default value: `[]`

##### <a name="-openssl--export--pem_key--in_pass"></a>`in_pass`

Data type: `Optional[String]`

PFX container password

Default value: `undef`

##### <a name="-openssl--export--pem_key--out_pass"></a>`out_pass`

Data type: `Optional[String]`

PEM key password

Default value: `undef`

### <a name="openssl--export--pkcs12"></a>`openssl::export::pkcs12`

Export a key pair to PKCS12 format

#### Parameters

The following parameters are available in the `openssl::export::pkcs12` defined type:

* [`basedir`](#-openssl--export--pkcs12--basedir)
* [`pkey`](#-openssl--export--pkcs12--pkey)
* [`cert`](#-openssl--export--pkcs12--cert)
* [`dynamic`](#-openssl--export--pkcs12--dynamic)
* [`ensure`](#-openssl--export--pkcs12--ensure)
* [`resources`](#-openssl--export--pkcs12--resources)
* [`in_pass`](#-openssl--export--pkcs12--in_pass)
* [`out_pass`](#-openssl--export--pkcs12--out_pass)
* [`chaincert`](#-openssl--export--pkcs12--chaincert)

##### <a name="-openssl--export--pkcs12--basedir"></a>`basedir`

Data type: `Stdlib::Absolutepath`

Directory where you want the export to be done. Must exists

##### <a name="-openssl--export--pkcs12--pkey"></a>`pkey`

Data type: `Stdlib::Absolutepath`

Private key

##### <a name="-openssl--export--pkcs12--cert"></a>`cert`

Data type: `Stdlib::Absolutepath`

Certificate

##### <a name="-openssl--export--pkcs12--dynamic"></a>`dynamic`

Data type: `Boolean`

dynamically renew PKCS12 file

Default value: `false`

##### <a name="-openssl--export--pkcs12--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Whether the PKCS12 file should exist

Default value: `present`

##### <a name="-openssl--export--pkcs12--resources"></a>`resources`

Data type: `Variant[Type, Array[Type]]`

List of resources to subscribe to for PKCS12 renewal

Default value: `[]`

##### <a name="-openssl--export--pkcs12--in_pass"></a>`in_pass`

Data type: `Optional[String]`

Private key password

Default value: `undef`

##### <a name="-openssl--export--pkcs12--out_pass"></a>`out_pass`

Data type: `Optional[String]`

PKCS12 password

Default value: `undef`

##### <a name="-openssl--export--pkcs12--chaincert"></a>`chaincert`

Data type: `Optional[String]`

Chain certificate to include in pkcs12

Default value: `undef`

## Resource types

### <a name="cert_file"></a>`cert_file`

Manages X.509 certificate files downloaded from a source location, saved in the specified format.

#### Properties

The following properties are available in the `cert_file` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `cert_file` type.

* [`format`](#-cert_file--format)
* [`path`](#-cert_file--path)
* [`provider`](#-cert_file--provider)
* [`source`](#-cert_file--source)

##### <a name="-cert_file--format"></a>`format`

Valid values: `der`, `pem`

Format in which the loaded certificate should be written to file.

Default value: `pem`

##### <a name="-cert_file--path"></a>`path`

Path to the file to manage

##### <a name="-cert_file--provider"></a>`provider`

The specific backend to use for this `cert_file` resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.

##### <a name="-cert_file--source"></a>`source`

The source file

### <a name="dhparam"></a>`dhparam`

A Diffie Helman parameter file

#### Properties

The following properties are available in the `dhparam` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `group`

group of the file

##### `mode`

mode of the file

##### `owner`

owner of the file

#### Parameters

The following parameters are available in the `dhparam` type.

* [`fastmode`](#-dhparam--fastmode)
* [`path`](#-dhparam--path)
* [`provider`](#-dhparam--provider)
* [`size`](#-dhparam--size)

##### <a name="-dhparam--fastmode"></a>`fastmode`

Enable fast mode

Default value: `false`

##### <a name="-dhparam--path"></a>`path`

The path of the file

##### <a name="-dhparam--provider"></a>`provider`

The specific backend to use for this `dhparam` resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.

##### <a name="-dhparam--size"></a>`size`

Valid values: `%r{\d+}`

The key size

Default value: `512`

### <a name="ssl_pkey"></a>`ssl_pkey`

An SSL private key

#### Properties

The following properties are available in the `ssl_pkey` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `group`

group of the file

##### `mode`

mode of the file

##### `owner`

owner of the file

#### Parameters

The following parameters are available in the `ssl_pkey` type.

* [`authentication`](#-ssl_pkey--authentication)
* [`curve`](#-ssl_pkey--curve)
* [`password`](#-ssl_pkey--password)
* [`path`](#-ssl_pkey--path)
* [`provider`](#-ssl_pkey--provider)
* [`size`](#-ssl_pkey--size)

##### <a name="-ssl_pkey--authentication"></a>`authentication`

Valid values: `rsa`, `ec`

The authentication algorithm

Default value: `rsa`

##### <a name="-ssl_pkey--curve"></a>`curve`

The EC curve

Default value: `secp384r1`

##### <a name="-ssl_pkey--password"></a>`password`

The optional password for the key

##### <a name="-ssl_pkey--path"></a>`path`

The path to the key

##### <a name="-ssl_pkey--provider"></a>`provider`

The specific backend to use for this `ssl_pkey` resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.

##### <a name="-ssl_pkey--size"></a>`size`

Valid values: `%r{\d+}`

The key size for RSA keys

Default value: `2048`

### <a name="x509_cert"></a>`x509_cert`

An x509 certificate

#### Properties

The following properties are available in the `x509_cert` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `group`

group of the file

##### `mode`

mode of the file

##### `owner`

owner of the file

#### Parameters

The following parameters are available in the `x509_cert` type.

* [`ca`](#-x509_cert--ca)
* [`cakey`](#-x509_cert--cakey)
* [`cakey_password`](#-x509_cert--cakey_password)
* [`csr`](#-x509_cert--csr)
* [`days`](#-x509_cert--days)
* [`force`](#-x509_cert--force)
* [`password`](#-x509_cert--password)
* [`path`](#-x509_cert--path)
* [`private_key`](#-x509_cert--private_key)
* [`provider`](#-x509_cert--provider)
* [`req_ext`](#-x509_cert--req_ext)
* [`template`](#-x509_cert--template)

##### <a name="-x509_cert--ca"></a>`ca`

The optional ca certificate filepath

##### <a name="-x509_cert--cakey"></a>`cakey`

The optional ca private key filepath

##### <a name="-x509_cert--cakey_password"></a>`cakey_password`

The optional CA key password

##### <a name="-x509_cert--csr"></a>`csr`

The optional certificate signing request path

##### <a name="-x509_cert--days"></a>`days`

Valid values: `%r{\d+}`

The validity of the certificate

Default value: `3650`

##### <a name="-x509_cert--force"></a>`force`

Valid values: `true`, `false`

Whether to replace the certificate if the private key mismatches

Default value: `false`

##### <a name="-x509_cert--password"></a>`password`

The optional password for the private key

##### <a name="-x509_cert--path"></a>`path`

The path to the certificate

##### <a name="-x509_cert--private_key"></a>`private_key`

The path to the private key

##### <a name="-x509_cert--provider"></a>`provider`

The specific backend to use for this `x509_cert` resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.

##### <a name="-x509_cert--req_ext"></a>`req_ext`

Valid values: `true`, `false`, `yes`, `no`

Whether adding v3 SAN from config

Default value: `false`

##### <a name="-x509_cert--template"></a>`template`

The template to use

### <a name="x509_request"></a>`x509_request`

An x509 certificate signing request

#### Properties

The following properties are available in the `x509_request` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `group`

group of the file

##### `mode`

mode of the file

##### `owner`

owner of the file

#### Parameters

The following parameters are available in the `x509_request` type.

* [`encrypted`](#-x509_request--encrypted)
* [`force`](#-x509_request--force)
* [`password`](#-x509_request--password)
* [`path`](#-x509_request--path)
* [`private_key`](#-x509_request--private_key)
* [`provider`](#-x509_request--provider)
* [`template`](#-x509_request--template)

##### <a name="-x509_request--encrypted"></a>`encrypted`

Valid values: `true`, `false`

Whether to generate the key unencrypted. This is needed by some applications like OpenLDAP

Default value: `true`

##### <a name="-x509_request--force"></a>`force`

Valid values: `true`, `false`

Whether to replace the certificate if the private key mismatches

Default value: `false`

##### <a name="-x509_request--password"></a>`password`

The optional password for the private key

##### <a name="-x509_request--path"></a>`path`

The path of the certificate signing request

##### <a name="-x509_request--private_key"></a>`private_key`

The path of the private key

##### <a name="-x509_request--provider"></a>`provider`

The specific backend to use for this `x509_request` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="-x509_request--template"></a>`template`

The template to use

## Functions

### <a name="openssl--cert_aia_caissuers"></a>`openssl::cert_aia_caissuers`

Type: Ruby 4.x API

Extract a X509 certificate for x509v3 extensions, search for Authority Information Access extension and return the
contents caIssuers access method.
For details see [rfc5280#section-4.2.2](https://tools.ietf.org/html/rfc5280#section-4.2.2).

Parameter: path to ssl certificate

#### `openssl::cert_aia_caissuers(String $certfile)`

Extract a X509 certificate for x509v3 extensions, search for Authority Information Access extension and return the
contents caIssuers access method.
For details see [rfc5280#section-4.2.2](https://tools.ietf.org/html/rfc5280#section-4.2.2).

Parameter: path to ssl certificate

Returns: `Any` contents of the caIssuers access method of authorityInfoAccess extension, or nil if not found

##### `certfile`

Data type: `String`

Path to the certificate to inspect

### <a name="openssl--cert_date_valid"></a>`openssl::cert_date_valid`

Type: Ruby 4.x API

Parameter: path to ssl certificate

#### `openssl::cert_date_valid(String $certfile)`

Parameter: path to ssl certificate

Returns: `Any` false if the certificate is expired or not yet valid,

##### `certfile`

Data type: `String`

The certificate file to check.

